@@ -1,10 +1,9 @@
 # 2022.3.5
 from app.dmdsk import *
 
-def run():
+def run(rid=2575450):
 	
 	st.title("rid-scores")
-	rid = st.text_input("input a rid", "2575450")
 	res = {eidv:redis.dsk.hget(eidv,'score') for eidv in eidv_list(int(rid))}
 	st.write(res) 
 
