@@ -66,7 +66,7 @@ def from_docbin(bs):
 	return list(spacy.tokens.DocBin().from_bytes(bs).get_docs(spacy.nlp.vocab))[0] if bs else None
 
 if not hasattr(spacy, 'nlp'):
-	spacy.nlp		= spacy.load('en_core_web_lg') # 3.4.1
+	spacy.nlp		= spacy.load(os.getenv('spacy_model','en_core_web_lg')) # 3.4.1
 	spacy.tobs		= to_docbin # for old codes
 	spacy.frombs	= from_docbin
 	spacy.from_json = lambda arr: Doc(spacy.nlp.vocab).from_json(arr) # added 2022.8.19
