@@ -1,11 +1,12 @@
-# 2022.8.15 , cp from esjson_load.py 
+# 2022.8.15 , cp from esjson_load.py | en(sid, src ( bnc,dic,nyt,gzjc) )
 import json,fire,sys, os, hashlib ,time , requests, fileinput, so
 from elasticsearch import Elasticsearch,helpers
 
 def esjson_load(infile, index:str=None, batch=10000, refresh:bool=True, eshost='127.0.0.1',esport=9200): 
 	''' python3 -m so.loades gzjc.esjson.gz '''
 	es	  = Elasticsearch([ f"http://{eshost}:{esport}" ])  
-	if not index : index = infile.split('.')[0]
+	name  = infile.split('.')[0]
+	if not index : index = name
 	print(">>started: " , infile, index, flush=True )
 	if refresh or not es.indices.exists(index=index): 
 		if es.indices.exists(index=index):es.indices.delete(index=index)
@@ -15,7 +16,8 @@ def esjson_load(infile, index:str=None, batch=10000, refresh:bool=True, eshost='
 	for line in fileinput.input(infile,openhook=fileinput.hook_compressed): 
 		try:
 			arr = json.loads(line.strip())
-			actions.append( {'_op_type':'index', '_index':index, '_id': arr.get('_id',None), '_source': arr.get('_source',{}) } )
+			id = f"{name}-{arr.get('_id','0')}"   # change to md5, to avoid duplicated snt 
+			actions.append( {'_op_type':'index', '_index':index, '_id': id, '_source': dict(arr.get('_source',{}), **{"id":id, "src": name}) } )
 			if len(actions) >= batch: 
 				helpers.bulk(client=es,actions=actions, raise_on_error=False)
 				print ( actions[-1], flush=True)
@@ -32,4 +34,16 @@ if __name__ == '__main__':
 {"_index": "gzjc", "_type": "_doc", "_id": "2897-stype", "_source": {"src": 2897, "tag": "simple_snt", "type": "stype"}}
 import warnings
 warnings.filterwarnings("ignore")
+
+POST /_reindex?pretty
+{
+  "source": {
+    "index": "gzjc"
+  },
+  "dest": {
+    "index": "en"
+  }
+}
+
+POST my-new-index-000001/_search?size=0&filter_path=hits.total
 '''
\ No newline at end of file
