@@ -1,6 +1,7 @@
 # 2022.3.10
-import requests 
+import requests,re,time
 from collections import	Counter, defaultdict
+now	= lambda: time.strftime('%Y.%m.%d %H:%M:%S',time.localtime(time.time()))
 
 import hashlib
 sntmd5	= lambda sntarr: " ".join([hashlib.md5(snt.strip().lower().encode("utf-8")).hexdigest() for snt in sntarr if len(snt) > 1])
@@ -17,11 +18,19 @@ def likelihood(a,b,c,d, minus=None):  #from: http://ucrel.lancs.ac.uk/llwizard.h
 		E2 = d * (a + b) / (c + d)
 		G2 = round(2 * ((a * ln(a / E1)) + (b * ln(b / E2))), 2)
 		if minus or  (minus is None and a * d < b * c): G2 = 0 - G2 #if minus or  (minus is None and a/c < b/d): G2 = 0 - G2
-		return G2
+		return round(G2,1)
 	except Exception as e:
 		print ("likelihood ex:",e, a,b,c,d)
 		return 0
 
+def logdice(xy, x, y): # https://www.fi.muni.cz/usr/sojka/download/raslan2008/13.pdf
+	return round(14  + ln ( 2 * xy/ (x+y), 2),1)
+#print (logdice( 1, 23, 56) )
+
+from dic import lemma_lex
+lexlist		= lambda lemma='open', sepa="|": sepa.join(list(lemma_lex.lemma_lex.get(lemma, [lemma]))) #opens|openest|opened|opener|opening|open
+highlight	= lambda snt='I open the door.', words='open|opened|door': re.sub(rf'\b({words})\b', r'<b>\g<0></b>', snt) if words else snt
+
 def  si_to_es(si, index, batch=10000, eshost='127.0.0.1',esport=9200): 
 	''' ie: spellerr, added 2022.9.6 '''
 	print (len(si), index,  flush=True) 
