@@ -17,8 +17,24 @@ def frame_snts(snts:list=["George returned to Berlin to return his hat.","He had
 	''' ["George returned to Berlin to return his hat.","He had a look at different hats."]	'''
 	return { snt: frame_snt(snt) for snt in snts }
 
+def walk(index, type:str='snt', eshost:str='es.corpusly.com:9200'):
+	''' 2022.8.22 '''
+	import requests 
+	print ('start to walk:', index, flush=True)
+	cursor=''
+	while True : 
+		res = requests.post(f"http://{eshost}/_sql", json={"query":f"select src, snt from {index} where type='{type}'", "cursor":cursor}).json() 
+		for src, snt in  res.get('rows',[]):
+			frames  = [ ar['value'] for ar in frame_snt(snt).get('all labels',[]) ] 
+			if not frames: continue
+			requests.put(f"http://{eshost}/{index}/_doc/{src}-frame", json={"frame": frames, "type":"frame", "src":src}).text
+		cursor = res.get('cursor','') 
+		if not cursor: break
+	print ('finished walking:', index, flush=True)
+
 if __name__ == '__main__': # read 'snt' from es,  parse , and submit back to ES, with type='frame' 
-	print (frame_snt())
+	import fire
+	fire.Fire({"walk":walk, "hello": frame_snt})
 
 @app.get('/flair/sentiment')
 def classify_sentiment(snt:str="He had a look at different hats."): 
