@@ -17,7 +17,7 @@ def snts_embeddings(snts:list=["This is an example sentence", "Each sentence is
 	embeddings = sbert(name).encode(snts)
 	return [ (sentence, embedding.tolist()) for sentence, embedding in zip(snts, embeddings)]
 
-@app.post('/sbert/cos_sim', tags=["sbert"])
+@app.get('/sbert/cos_sim', tags=["sbert"])
 def snts_cos_sim(snt0:str="This is a red cat with a hat.", snt1:str="Have you seen my red cat?", name:str="all-MiniLM-L6-v2"): 
 	''' https://www.sbert.net/docs/quickstart.html '''
 	from sentence_transformers import util
@@ -27,6 +27,14 @@ def snts_cos_sim(snt0:str="This is a red cat with a hat.", snt1:str="Have you se
 	cos_sim = util.cos_sim(emb1, emb2)
 	return cos_sim.tolist()[0][0]
 
+@app.post('/sbert/cos_sim', tags=["sbert"])
+def snts_cos_sim_post(refers:list=["This is a red cat with a hat.", "That is a red cat with hats."], snt:str="Have you seen my red cat?", name:str="all-MiniLM-L6-v2"): 
+	''' 2022.10.16 '''
+	from sentence_transformers import util
+	model = sbert(name) 
+	emb   = model.encode(snt)
+	return [ {"refer":snt, "score": util.cos_sim(emb, model.encode(snt)).tolist()[0][0] }   for snt in refers]
+
 @app.post('/sbert/query_answers', tags=["sbert"])
 def snts_query_answers(answers:list, query:str="How big is London"): 
 	''' ["London has 9,787,426 inhabitants at the 2011 census", "London is known for its finacial district"] '''
