@@ -3,7 +3,7 @@ from uvirun import *
 from transformers import AutoTokenizer, AutoModelForSeq2SeqLM
 
 @app.post('/trans', tags=["trans"])
-def trans(examples:list=["I love you.","I am too tired to move on."], max_length:int=128, name:str="Helsinki-NLP/opus-mt-en-zh"):  
+def trans(examples:list=["I love you.","I am too tired to move on."], max_length:int=128, name:str="Helsinki-NLP/opus-mt-en-zh", asdic:bool=False):  
 	''' ["我来自北京。","锄禾日当午","能穿多少穿多少。"] | Helsinki-NLP/opus-mt-zh-en '''
 	if not hasattr(trans,name): 
 		setattr(trans, f"{name}_tokenizer", AutoTokenizer.from_pretrained(f"/data/model/trans/{name}") )
@@ -13,11 +13,11 @@ def trans(examples:list=["I love you.","I am too tired to move on."], max_length
 	inputs	  = tokenizer(examples, padding=True, return_tensors="pt")
 	outputs	  = model.generate(**inputs, max_length=max_length)
 	tgts	  = [tokenizer.decode(ids, skip_special_tokens=True) for ids in outputs]
-	return [ {"src": src, "tgt": tgt} for src, tgt in zip(examples, tgts) ]
+	return  {src: tgt for src, tgt in zip(examples, tgts)} if asdic else [ {"src": src, "tgt": tgt} for src, tgt in zip(examples, tgts) ]
 
 @app.get('/trans', tags=["trans"])
 def trans_get(text:str="I love you. I am too tired to move on.", max_length:int=128, name:str="Helsinki-NLP/opus-mt-en-zh"):  
-	return trans([text], max_length, name)
+	return trans([text], max_length, name, asdic=True).get(text, text ) 
 
 if __name__ == '__main__':	#uvicorn.run(app, host='0.0.0.0', port=8889)
 	print (trans()) 
